import requests

# Download the html link
def download_page(url):
    response = requests.get(url)
    return response.text

# Extract only the artists from the html
def parse_artists_page(page):
    lines = []
    for line in page.splitlines():
        if line.startswith("<a href=\"engenremap"):
            while line.find('target=_parent>') != -1:
                start = line.find('target=_parent>') + 15
                line = line[start:]
                end = line.find('</a>')
                lines.append(line[:end])
                line = line[end:]
            break
    return lines

# Extract only genres from the html
def parse_genres_page(page):
    lines = []
    for line in page.splitlines():
        if line.startswith("<div id=item"):
            start = line.find('>') + 1
            end = line.find('<a class=navlink')
            lines.append(line[start:end])
    return lines

# generate lists of artists
def generate_lists(genres):
    lists = []
    for genre in genres:
        lists.append(parse_genres_page(download_page("https://everynoise.com/engenremap-" + genre + ".html")))
    return lists

# Find common elements in lists
def common_elements(lists):
    common = []
    for i in range(len(lists[0])):
        for j in range(1, len(lists)):
            if lists[0][i] not in lists[j]:
                break
            if j == len(lists) - 1:
                common.append(lists[0][i])
    return common

# lowercase + remove spaces for genres
def clean_list(list):
    for i in range(len(list)):
        list[i] = list[i].lower()
        list[i] = list[i].replace(" ", "")
    return list

# Generate the mashup
def generate_mashup(genres):
    clean_genres = clean_list(genres)
    lists = generate_lists(clean_genres)
    common = common_elements(lists)
    print("Mashup of " + ", ".join(genres) + ":")
    for artist in common:
        print(artist)

# Print artist genres
def print_genres(artist):
    page = download_page("https://everynoise.com/lookup.cgi?who=" + artist)
    genres = parse_artists_page(page)
    print("Genres for " + artist + ":")
    for genre in genres:
        print(genre)

def main():
    search_item = input("1. Search for artist genres\n2. Mash Genres\nPick 1 or 2:")
    if search_item == "1":
        artist = input("Artist name: ")
        print_genres(artist)
    elif search_item == "2":
        genres = input("Enter genres: ").split(", ")
        generate_mashup(genres)
    else:
        print("Invalid input")

if __name__ == "__main__":
    main()